Method: HasRemote.synchronize!
- Defined in:
- lib/has_remote.rb
.synchronize! ⇒ Object
Updates cached attributes, destroys deleted records and adds new records of all models that have a remote. Also see Synchronizable.
27 28 29 |
# File 'lib/has_remote.rb', line 27 def self.synchronize! models.each(&:synchronize!) end |